==> huaweicloudsdkcdn-3.1.116-py2.py3-none-any.whl: huaweicloudsdkcdn/v2/model/show_bandwidth_calc_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowBandwidthCalcResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'bandwidth_calc': 'dict(str, object)'
    }

    attribute_map = {
        'bandwidth_calc': 'bandwidth_calc'
    }

    def __init__(self, bandwidth_calc=None):
        """ShowBandwidthCalcResponse

        The model defined in huaweicloud sdk

        :param bandwidth_calc: 95峰值，日峰值月平均线信息
        :type bandwidth_calc: dict(str, object)
        """
        
        super(ShowBandwidthCalcResponse, self).__init__()

        self._bandwidth_calc = None
        self.discriminator = None

        if bandwidth_calc is not None:
            self.bandwidth_calc = bandwidth_calc

    @property
    def bandwidth_calc(self):
        """Gets the bandwidth_calc of this ShowBandwidthCalcResponse.

        95峰值，日峰值月平均线信息

        :return: The bandwidth_calc of this ShowBandwidthCalcResponse.
        :rtype: dict(str, object)
        """
        return self._bandwidth_calc

    @bandwidth_calc.setter
    def bandwidth_calc(self, bandwidth_calc):
        """Sets the bandwidth_calc of this ShowBandwidthCalcResponse.

        95峰值，日峰值月平均线信息

        :param bandwidth_calc: The bandwidth_calc of this ShowBandwidthCalcResponse.
        :type bandwidth_calc: dict(str, object)
        """
        self._bandwidth_calc = bandwidth_calc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowBandwidthCalcResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcdn-3.1.151-py2.py3-none-any.whl: huaweicloudsdkcdn/v2/model/show_bandwidth_calc_response.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.sdk_response import SdkResponse
from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ShowBandwidthCalcResponse(SdkResponse):

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'bandwidth_calc': 'dict(str, object)'
    }

    attribute_map = {
        'bandwidth_calc': 'bandwidth_calc'
    }

    def __init__(self, bandwidth_calc=None):
        r"""ShowBandwidthCalcResponse

        The model defined in huaweicloud sdk

        :param bandwidth_calc: 95峰值，日峰值月平均线信息
        :type bandwidth_calc: dict(str, object)
        """
        
        super(ShowBandwidthCalcResponse, self).__init__()

        self._bandwidth_calc = None
        self.discriminator = None

        if bandwidth_calc is not None:
            self.bandwidth_calc = bandwidth_calc

    @property
    def bandwidth_calc(self):
        r"""Gets the bandwidth_calc of this ShowBandwidthCalcResponse.

        95峰值，日峰值月平均线信息

        :return: The bandwidth_calc of this ShowBandwidthCalcResponse.
        :rtype: dict(str, object)
        """
        return self._bandwidth_calc

    @bandwidth_calc.setter
    def bandwidth_calc(self, bandwidth_calc):
        r"""Sets the bandwidth_calc of this ShowBandwidthCalcResponse.

        95峰值，日峰值月平均线信息

        :param bandwidth_calc: The bandwidth_calc of this ShowBandwidthCalcResponse.
        :type bandwidth_calc: dict(str, object)
        """
        self._bandwidth_calc = bandwidth_calc

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ShowBandwidthCalcResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
